
.. image:: https://img.shields.io/pypi/v/esbmtk.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/esbmtk/

.. image:: https://img.shields.io/badge/Python-3.9-blue.svg
    :alt: Python-3.9 badge
    :target: https://www.python.org/

.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

.. image:: https://readthedocs.org/projects/esbmtk/badge/?version=latest
    :target: https://esbmtk.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

1 ESBMTK - The  Earth-sciences box modeling toolkit
---------------------------------------------------

ESBMTK is a python library that aims to simplify typical box modeling
projects in the Earth-Sciences. The basic API is now stable, but the code to deploy complex models is still being improved.
See the tutorial at `https://esbmtk.readthedocs.io/en/latest/ESBMTK-Tutorial.html <https://esbmtk.readthedocs.io/en/latest/ESBMTK-Tutorial.html>`_

2 Todo
------

- expand the documentation

- provide more examples

- do more testing

3 License
---------

ESBMTK: A general purpose Earth Science box model toolkit
Copyright (C), 2020 Ulrich G. Wortmann

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see `https://www.gnu.org/licenses/gpl-3.0.en.html <https://www.gnu.org/licenses/gpl-3.0.en.html>`_
